@@ -20,7 +20,8 @@ from typing import Union
 from urllib.parse import urlparse
 import fsspec
 import numpy as np
-import oci
+import oci.data_science
+import oci.exceptions
 import pandas as pd
 import pkg_resources
 import python_jsonschema_objects as pjs
@@ -85,11 +86,11 @@ class InvalidDataType(Exception):
 SAMPLE_RUNTIME_YAML = f"""
 MODEL_ARTIFACT_VERSION: '{MODEL_ARTIFACT_VERSION}'
 MODEL_DEPLOYMENT:
-INFERENCE_CONDA_ENV:
-    INFERENCE_ENV_SLUG: <slug of the conda pack>
-    INFERENCE_ENV_TYPE: <data_science or published>
-    INFERENCE_ENV_PATH: oci://<bucket-name>@<namespace>/<prefix>/<env>.tar.gz
-    INFERENCE_PYTHON_VERSION: <python version>
+    INFERENCE_CONDA_ENV:
+        INFERENCE_ENV_SLUG: <slug of the conda pack>
+        INFERENCE_ENV_TYPE: <data_science or published>
+        INFERENCE_ENV_PATH: oci://<bucket-name>@<namespace>/<prefix>/<env>.tar.gz
+        INFERENCE_PYTHON_VERSION: <python version>
 """
 
 
@@ -162,12 +163,16 @@ class ModelArtifact(Introspectable):
         model_file_name: str
             File to determine model serilization type.
         inference_conda_env: str
-            The inferred conda env.
+            The inferred conda env. If provided, the value will be set in the runtime.yaml.
+            This is expected to be full oci URI format - `oci://{bucket}@{namespace}/path/to/condapack`
         data_science_env: book
             Determine whether in ODSC conda env.
         ignore_deployment_error: bool
             Determine whether to turn off logging for deployment error.
             If set to True, the prepare will ignore all the errors that may impact model deployment.
+        inference_python_version: str Optional, default None
+            If provided, the value will be set in the runtime.yaml that is produced for model deployment
+
 
         Methods
         -------
@@ -202,6 +207,7 @@ class ModelArtifact(Introspectable):
             Populates input and output schema.
         introspect(self) -> pd.DataFrame
             Runs model introspection.
+
         """
         self.artifact_dir = (
             artifact_dir[:-1] if artifact_dir.endswith("/") else artifact_dir
@@ -224,7 +230,12 @@ class ModelArtifact(Introspectable):
             if "CONDA_PREFIX" in os.environ and "NB_SESSION_OCID" in os.environ:
                 self._generate_runtime_yaml(model_file_name=model_file_name)
             else:
-                self._generate_empty_runtime_yaml(model_file_name=model_file_name)
+                self._generate_empty_runtime_yaml(
+                    model_file_name=model_file_name,
+                    data_science_env=data_science_env,
+                    inference_conda_env=inference_conda_env,
+                    inference_python_version=inference_python_version,
+                )
             self.version = MODEL_ARTIFACT_VERSION
 
         # This will re-install the env which the model artifact was trained in.
@@ -367,13 +378,45 @@ class ModelArtifact(Introspectable):
         ns = builder.build_classes()
         return ns
 
-    def _generate_empty_runtime_yaml(self, model_file_name="model.onnx"):
+    def _generate_empty_runtime_yaml(
+        self,
+        model_file_name="model.onnx",
+        data_science_env=False,
+        inference_conda_env=None,
+        inference_python_version=None,
+    ):
+        if self.progress:
+            self.progress.update("Creating runtime.yaml configuration")
         logger.warning(
             "Generating runtime.yaml template. This file needs to be updated with valid values before saving to model catalog for a successful deployment"
         )
-        content = SAMPLE_RUNTIME_YAML
+        content = yaml.load(SAMPLE_RUNTIME_YAML, Loader=yaml.FullLoader)
+        print(
+            f"The conda env info is {inference_conda_env} and {inference_python_version}"
+        )
+        if inference_conda_env:
+            content["MODEL_DEPLOYMENT"]["INFERENCE_CONDA_ENV"][
+                "INFERENCE_ENV_SLUG"
+            ] = ""
+            content["MODEL_DEPLOYMENT"]["INFERENCE_CONDA_ENV"][
+                "INFERENCE_ENV_TYPE"
+            ] = ""
+            content["MODEL_DEPLOYMENT"]["INFERENCE_CONDA_ENV"][
+                "INFERENCE_ENV_PATH"
+            ] = inference_conda_env
+        if inference_python_version:
+            content["MODEL_DEPLOYMENT"]["INFERENCE_CONDA_ENV"][
+                "INFERENCE_PYTHON_VERSION"
+            ] = str(inference_python_version)
+
+        content["MODEL_DEPLOYMENT"]["INFERENCE_CONDA_ENV"]["INFERENCE_ENV_TYPE"] = (
+            PACK_TYPE.SERVICE_PACK.value
+            if data_science_env
+            else PACK_TYPE.USER_CUSTOM_PACK.value
+        )
+
         with open(os.path.join(self.artifact_dir, "runtime.yaml"), "w") as outfile:
-            outfile.write(content)
+            yaml.dump(content, outfile)
 
     def _generate_runtime_yaml(self, model_file_name="model.onnx"):
         if self.progress:
@@ -641,6 +684,8 @@ class ModelArtifact(Introspectable):
         training_id: str = None,
         timeout: int = None,
         ignore_introspection=True,
+        freeform_tags=None,
+        defined_tags=None,
     ):
         """
         Saves this model artifact in model catalog.
@@ -675,6 +720,10 @@ class ModelArtifact(Introspectable):
         ignore_introspection: bool, optional
             Determine whether to ignore the result of model introspection or not.
             If set to True, the save will ignore all model introspection errors.
+        freeform_tags : dict(str, str), optional
+            Freeform tags for the model, by default None
+        defined_tags : dict(str, dict(str, object)), optional
+            Defined tags for the model, by default None
 
         Examples
         ________
@@ -773,6 +822,12 @@ class ModelArtifact(Introspectable):
                 client_auth["client_kwargs"] = {}
             client_auth["client_kwargs"]["timeout"] = timeout
 
+        if freeform_tags and not isinstance(freeform_tags, dict):
+            raise TypeError("Freeform tags must be a dictionary.")
+
+        if defined_tags and not isinstance(defined_tags, dict):
+            raise TypeError("Defined tags must be a dictionary.")
+
         self._validate_metadata()
         self._validate_schema()
 
@@ -807,6 +862,8 @@ class ModelArtifact(Introspectable):
                 display_name=display_name,
                 description=description,
                 project_id=project_id,
+                freeform_tags=freeform_tags,
+                defined_tags=defined_tags,
             )
         except oci.exceptions.RequestException as e:
             if "The write operation timed out" in str(e):
