@@ -99,23 +99,50 @@ def prepare_generic_model(
     * score.py
 
     Usage:
+    -----
+    >>> import cloudpickle
+    >>> import os
+    >>> from sklearn.linear_model import LogisticRegression
+    >>> from sklearn.datasets import make_classification
+    >>> import ads
     >>> from ads.common.model_export_util import prepare_generic_model
-    >>> prepare_generic_model('/home/datascience/model')
-
-    >>> prepare_generic_model(
-            model_path = '/home/datascience/cbhol/lab/model_' + datetime.now().strftime("%m%d%Y%H%M%S"),
-            force_overwrite=True,
-            fn_artifact_files_included=False,
-            inference_conda_env="oci://bucket_name@namespace/pack_to_conda_pack"
-        )
-
-    >>> prepare_generic_model(
-            model_path = '/home/datascience/cbhol/lab/model_' + datetime.now().strftime("%m%d%Y%H%M%S"),
-            force_overwrite=True,
-            fn_artifact_files_included=False,
-            inference_python_version="3.7",
-            inference_conda_env="oci://bucket_name@namespace/pack_to_conda_pack"
-        )
+    >>> import yaml
+    >>>
+    >>> ads.set_auth('api_keys', profile='DEFAULT')
+    >>> model_artifact_location = os.path.expanduser('~/myusecase/model/')
+    >>> inference_conda_env="oci://my-bucket@namespace/conda_environments/cpu/Data Exploration and Manipulation for CPU Python 3.7/2.0/dataexpl_p37_cpu_v2"
+    >>> inference_python_version = "3.7"
+    >>> if not os.path.exists(model_artifact_location):
+    ...     os.makedirs(model_artifact_location)
+    >>> X, y = make_classification(n_samples=100, n_features=20, n_classes=2)
+    >>> lrmodel = LogisticRegression().fit(X, y)
+    >>> with open(os.path.join(model_artifact_location, 'model.pkl'), "wb") as mfile:
+    ...     cloudpickle.dump(lrmodel, mfile)
+    >>> modelartifact = prepare_generic_model(
+    ...     model_artifact_location,
+    ...     model = 'model.pkl',
+    ...     force_overwrite=True,
+    ...     inference_conda_env=inference_conda_env,
+    ...     ignore_deployment_error=True,
+    ...     inference_python_version=inference_python_version
+    ... )
+    >>> modelartifact.reload() # Call reload to update the ModelArtifact object with the generated score.py
+    >>> assert len(modelartifact.predict(X[:5])['prediction']) == 5 #Test the generated score.py works. This may require customization.
+    >>> with open(os.path.join(model_artifact_location, "runtime.yaml")) as rf:
+    ...     content = yaml.load(rf, Loader=yaml.FullLoader)
+    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_ENV_PATH'] == inference_conda_env
+    ...     assert content['MODEL_DEPLOYMENT']['INFERENCE_CONDA_ENV']['INFERENCE_PYTHON_VERSION'] == inference_python_version
+    >>> # Save Model to model artifact
+    >>> ocimodel = modelartifact.save(
+    ...     project_id="oci1......", # OCID of the project to which the model to be associated
+    ...     compartment_id="oci1......", # OCID of the compartment where the model will reside
+    ...     display_name="LRModel_01",
+    ...     description="My Logistic Regression Model",
+    ...     ignore_pending_changes=True,
+    ...     timeout=100,
+    ...     ignore_introspection=True,
+    ... )
+    >>> print(f"The OCID of the model is: {ocimodel.id}")
 
     Parameters
     ----------
@@ -158,6 +185,8 @@ def prepare_generic_model(
         For example, {numpy: 1.21.1}.
     progress : int, default: None
         max number of progress.
+    inference_python_version: str, default:None.
+        If provided will be added to the generated runtime yaml
 
     Returns
     -------
@@ -211,8 +240,6 @@ def prepare_generic_model(
                     logger.warning(
                         f"As force_overwrite is set to True, all the existing files in the {model_path} will be removed"
                     )
-                    # deleting all the content in the existing directory
-                    shutil.rmtree(model_path)
                 else:
                     raise ValueError(
                         "Directory already exists, set force_overwrite to True if you wish to overwrite."
@@ -241,6 +268,10 @@ def prepare_generic_model(
         model_artifact_args = {}
         if "inference_conda_env" in kwargs:
             model_artifact_args["inference_conda_env"] = kwargs["inference_conda_env"]
+        if "inference_python_version" in kwargs:
+            model_artifact_args["inference_python_version"] = kwargs[
+                "inference_python_version"
+            ]
         if "data_science_env" in kwargs:
             model_artifact_args["data_science_env"] = kwargs["data_science_env"]
         if "ignore_deployment_error" in kwargs:
@@ -252,7 +283,6 @@ def prepare_generic_model(
             reload=False,
             create=True,
             progress=progress,
-            inference_python_version=kwargs.get("inference_python_version", None),
             **model_artifact_args,
         )
 
@@ -568,12 +598,13 @@ def _mxnet_to_onnx(model=None, target_dir=None, X=None, y=None, **kwargs):
         onnx_file_path=onnx_file,
     )
 
-    def _log_automatic_serialization_keras(e):
-        logger.error(
-            f"The following error occured: {e}. "
-            f"This may be because automatic serialization for Keras models is not supported. "
-            f"Use `prepare_generic_model()` method to manually serialize the model."
-        )
+
+def _log_automatic_serialization_keras(e):
+    logger.error(
+        f"The following error occured: {e}. "
+        f"This may be because automatic serialization for Keras models is not supported. "
+        f"Use `prepare_generic_model()` method to manually serialize the model."
+    )
 
 
 # # Note to developers: If you make any changes to this class, please copy and paste those changes over to
