@@ -8,7 +8,7 @@ import logging
 import time
 from typing import Union
 
-import oci
+import oci.logging
 from ads.common.oci_mixin import OCIModelMixin, OCIWorkRequestMixin
 from ads.common.oci_resource import OCIResource, ResourceNotFoundError
 
