@@ -22,16 +22,20 @@ import dask.dataframe as dd
 import numpy as np
 import pandas as pd
 from IPython import get_ipython
+import dask
 
 from sklearn.model_selection import train_test_split as sklearn_train_test_split
 
 from IPython.core.display import display, HTML
 
+from ads.common import logger
+from ads.common.deprecate import deprecated
 from ads.dataset.progress import TqdmProgressBar, DummyProgressBar
+from typing import Union
 
 # For Model / Model Artifact libraries
-lib_translator = {'sklearn': 'scikit-learn'}
-module_ignore = ['builtins', 'ads', 'automl', 'mlx']
+lib_translator = {"sklearn": "scikit-learn"}
+module_ignore = ["builtins", "ads", "automl", "mlx"]
 
 # up-sample if length of dataframe is less than or equal to MAX_LEN_FOR_UP_SAMPLING
 MAX_LEN_FOR_UP_SAMPLING = 5000
@@ -39,17 +43,24 @@ MAX_LEN_FOR_UP_SAMPLING = 5000
 # down-sample if ratio of minority to majority class is greater than or equal to MIN_RATIO_FOR_DOWN_SAMPLING
 MIN_RATIO_FOR_DOWN_SAMPLING = 1 / 20
 
+# Maximum distinct values by cardinality will be used for plotting
+MAX_DISPLAY_VALUES = 10
+
 random_state = 42
 test_size = 0.3
 date_format = "%Y-%m-%d %H:%M:%S"
 
 # at this time, we only support regression and classification tasks.
-ml_task_types = Enum('ml_task_types',
-                     'REGRESSION BINARY_CLASSIFICATION MULTI_CLASS_CLASSIFICATION BINARY_TEXT_CLASSIFICATION '
-                     'MULTI_CLASS_TEXT_CLASSIFICATION UNSUPPORTED')
+ml_task_types = Enum(
+    "ml_task_types",
+    "REGRESSION BINARY_CLASSIFICATION MULTI_CLASS_CLASSIFICATION BINARY_TEXT_CLASSIFICATION "
+    "MULTI_CLASS_TEXT_CLASSIFICATION UNSUPPORTED",
+)
 
-mpl.rcParams['image.cmap'] = "BuGn"
-mpl.rcParams['axes.prop_cycle'] = cycler(color=['teal', 'blueviolet', 'forestgreen', 'peru', 'y', 'dodgerblue', 'r'])
+mpl.rcParams["image.cmap"] = "BuGn"
+mpl.rcParams["axes.prop_cycle"] = cycler(
+    color=["teal", "blueviolet", "forestgreen", "peru", "y", "dodgerblue", "r"]
+)
 
 # sqlalchemy engines
 _engines = {}
@@ -68,6 +79,7 @@ def get_compute_accelerator_ncores():
     Returns the number of accelerator cores
     """
     from ads.environment import ml_runtime
+
     return sum(ml_runtime.compute_accelerator().ncores().values())
 
 
@@ -75,22 +87,27 @@ def get_oci_config():
     """
     Returns the OCI config location, and the OCI config profile.
     """
-    oci_config_location = os.environ.get('OCI_CONFIG_LOCATION', f"{os.environ['HOME']}/.oci/config")  # os.environ['HOME'] == home/datascience
+    oci_config_location = os.environ.get(
+        "OCI_CONFIG_LOCATION", f"{os.environ['HOME']}/.oci/config"
+    )  # os.environ['HOME'] == home/datascience
     oci_config_profile = os.environ.get("OCI_CONFIG_PROFILE", "DEFAULT")
     return oci_config_location, oci_config_profile
 
+
 def oci_key_location():
     """
     Returns the OCI key location
     """
-    return os.environ.get("OCI_CONFIG_DIR", os.path.join(os.path.expanduser('~'),'.oci'))
+    return os.environ.get(
+        "OCI_CONFIG_DIR", os.path.join(os.path.expanduser("~"), ".oci")
+    )
 
 
 def oci_config_file():
     """
     Returns the OCI config file location
     """
-    return os.path.join(oci_key_location(), 'config')
+    return os.path.join(oci_key_location(), "config")
 
 
 def oci_config_profile():
@@ -104,41 +121,41 @@ def numeric_pandas_dtypes():
     """
     Returns a list of the "numeric" pandas data types
     """
-    return ['int16', 'int32', 'int64', 'float16', 'float32', 'float64']
+    return ["int16", "int32", "int64", "float16", "float32", "float64"]
 
 
 def set_oci_config(oci_config_location, oci_config_profile):
-    '''
+    """
     :param oci_config_location: location of the config file, for example, ~/.oci/config
     :param oci_config_profile: The profile to load from the config file.  Defaults to "DEFAULT"
-    '''
+    """
     if not os.path.exists(f"{oci_config_location}"):
         raise ValueError("The oci config file doesn't exist.")
-    os.environ['OCI_CONFIG_LOCATION'] = oci_config_location
+    os.environ["OCI_CONFIG_LOCATION"] = oci_config_location
     os.environ["OCI_CONFIG_PROFILE"] = oci_config_profile
 
 
 def random_valid_ocid(prefix="ocid1.dataflowapplication.oc1.iad"):
     """
-    Generates a random valid ocid
+    Generates a random valid ocid.
 
     Parameters
     ----------
     prefix: `str`
-        A prefix, corresponding to a region location
+        A prefix, corresponding to a region location.
 
     Returns
     -------
     ocid: `str`
-        a valid ocid with the given prefix
+        a valid ocid with the given prefix.
     """
-    left, right = prefix.rsplit('.', 1)
-    fake = ''.join([random.choice(string.ascii_lowercase) for i in range(60)])
-    return f'{left}.{fake}'
+    left, right = prefix.rsplit(".", 1)
+    fake = "".join([random.choice(string.ascii_lowercase) for i in range(60)])
+    return f"{left}.{fake}"
 
 
 def get_dataframe_styles(max_width=75):
-    """styles used for dataframe, example usage:
+    """Styles used for dataframe, example usage:
 
         df.style\
             .set_table_styles(utils.get_dataframe_styles())\
@@ -148,42 +165,39 @@ def get_dataframe_styles(max_width=75):
     Returns
     -------
     styles: array
-        A list of dataframe table styler styles
-
+        A list of dataframe table styler styles.
     """
 
     alt_props = [
-        ('background-color', '#F8F8F8'),
+        ("background-color", "#F8F8F8"),
     ]
 
     th_props = [
-        ('font-size', '12px'),
-        ('text-align', 'center'),
-        ('font-weight', 'bold'),
-        ('background-color', '#D3D3D3'),
-        ('padding-left', '5px'),
-        ('padding-right', '5px'),
-        ('text-align', 'right')
+        ("font-size", "12px"),
+        ("text-align", "center"),
+        ("font-weight", "bold"),
+        ("background-color", "#D3D3D3"),
+        ("padding-left", "5px"),
+        ("padding-right", "5px"),
+        ("text-align", "right"),
     ]
 
     td_props = [
-        ('font-size', '12px'),
-        ('text_wrap', False),
-        ('white-space', 'nowrap'),
-        ('overflow', 'hidden'),
-        ('text-overflow', 'ellipsis'),
-        ('max-width', f'{max_width}px')
+        ("font-size", "12px"),
+        ("text_wrap", False),
+        ("white-space", "nowrap"),
+        ("overflow", "hidden"),
+        ("text-overflow", "ellipsis"),
+        ("max-width", f"{max_width}px"),
     ]
 
-    hover_props = [
-        ("background-color", "#D9EDFD")
-    ]
+    hover_props = [("background-color", "#D9EDFD")]
 
     styles = [
-        dict(selector='tbody tr:nth-child(even)', props=alt_props),
-        dict(selector='tbody tr:hover', props=hover_props),
+        dict(selector="tbody tr:nth-child(even)", props=alt_props),
+        dict(selector="tbody tr:hover", props=hover_props),
         dict(selector="th", props=th_props),
-        dict(selector="td", props=td_props)
+        dict(selector="td", props=td_props),
     ]
 
     return styles
@@ -193,7 +207,7 @@ def get_bootstrap_styles():
     """
     Returns HTML bootstrap style information
     """
-    return '''<style>
+    return """<style>
 
         code {
             padding: 2px 4px;
@@ -241,45 +255,43 @@ def get_bootstrap_styles():
         .label-duplicate-rows {
             background-color: #d90773;
         }
-    </style>'''
+    </style>"""
 
 
 def highlight_text(text):
-    """
-    Returns text with html highlights
+    """Returns text with html highlights.
     Parameters
     ----------
     text: String
-      The text to be highlighted
+      The text to be highlighted.
 
     Returns
     -------
     ht: String
-        The text with html highlight information
-
+        The text with html highlight information.
     """
-    return f'''<code style="background:yellow; color:black; padding-top: 5px; padding-bottom: 5px">
+    return f"""<code style="background:yellow; color:black; padding-top: 5px; padding-bottom: 5px">
         {text}
-    </code>'''.strip()
+    </code>""".strip()
 
 
 def horizontal_scrollable_div(html):
-    """Wrap html with the necessary html to make horizontal scrolling possible
+    """Wrap html with the necessary html to make horizontal scrolling possible.
 
-    example:
+    Examples
+    ________
 
-        display(HTML(utils.horizontal_scrollable_div(my_html)))
+    display(HTML(utils.horizontal_scrollable_div(my_html)))
 
     Parameters
     ----------
-    html : str
-        Your HTML to wrap
+    html: str
+        Your HTML to wrap.
 
     Returns
     -------
     type
-        wrapped HTML
-
+        Wrapped HTML.
     """
 
     return f"""
@@ -314,15 +326,16 @@ def horizontal_scrollable_div(html):
 # checks to see if in notebook mode
 #
 
+
 def is_notebook():
     """
-    Returns true if the environment is a jupyter notebook
+    Returns true if the environment is a jupyter notebook.
     """
     try:
         shell = get_ipython().__class__.__name__
-        if shell == 'ZMQInteractiveShell':  # pragma: no cover
+        if shell == "ZMQInteractiveShell":  # pragma: no cover
             return True  # Jupyter notebook or qtconsole
-        elif shell == 'TerminalInteractiveShell':
+        elif shell == "TerminalInteractiveShell":
             return False  # Terminal running IPython
         else:
             return False  # Other type (?)
@@ -338,78 +351,100 @@ def is_notebook():
 #
 def is_test():  # pragma: no cover
     """
-    Returns true if ADS is in test mode
+    Returns true if ADS is in test mode.
     """
     from ads import test_mode
+
     return test_mode
 
 
 def is_resource_principal_mode():  # pragma: no cover
     """
-    Returns true if ADS is in resource principal mode
+    Returns true if ADS is in resource principal mode.
     """
     from ads import resource_principal_mode
+
     return resource_principal_mode
 
 
+def oci_key_profile():
+    from ads import oci_key_profile
+
+    return oci_key_profile
+
+
 def is_documentation_mode():  # pragma: no cover
     """
-    Returns true if ADS is in documentation mode
+    Returns true if ADS is in documentation mode.
     """
     from ads import documentation_mode
+
     return documentation_mode
 
 
 def is_debug_mode():  # pragma: no cover
     """
-    Returns true if ADS is in debug mode
+    Returns true if ADS is in debug mode.
     """
     from ads import debug_mode
+
     return debug_mode
 
 
-def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"):  # pragma: no cover
-    """
-    prints in html formatted block one of tip|info|warn type
+@deprecated("2.3.1")
+def print_user_message(
+    msg, display_type="tip", see_also_links=None, title="Tip"
+):  # pragma: no cover
+    """This method is deprecated and will be removed in future releases.
+    Prints in html formatted block one of tip|info|warn type.
 
     Parameters
     ----------
-    msg: str or list
-        The actual message to display
+    msg : str or list
+        The actual message to display.
         display_type is "module', msg can be a list of [module name, module package name], i.e. ["automl", "ads[ml]"]
-    display_type: str (default 'tip')
-        The type of user message
-    see_also_links: list of tuples in the form of [('display_name', 'url')]
-    title: str (default 'tip')
-        The title of user message
+    display_type : str (default 'tip')
+        The type of user message.
+    see_also_links : list of tuples in the form of [('display_name', 'url')]
+    title : str (default 'tip')
+        The title of user message.
     """
 
-    if display_type.lower() == 'error' and not is_documentation_mode():
-        print("ERROR: {}".format(re.sub('<[^>]*>', '', msg)))
-    
-    if display_type.lower() == 'module':
+    if display_type.lower() == "error" and not is_documentation_mode():
+        print("ERROR: {}".format(re.sub("<[^>]*>", "", msg)))
+
+    if display_type.lower() == "module":
         if isinstance(msg, list()):
             module_name = msg[0]
             module_pkg = msg[1]
         else:
             module_name, module_pkg = msg, msg
-        print(f"ERROR: {module_name} module not found. Make sure you have installed {module_pkg} in order to download all of necessary modules.")
+        print(
+            f"ERROR: {module_name} module not found. Make sure you have installed {module_pkg} in order to download all of necessary modules."
+        )
 
     if is_documentation_mode() and is_notebook():
 
-        if display_type.lower() == 'tip':
+        if display_type.lower() == "tip":
 
-            if '\n' in msg:
+            if "\n" in msg:
                 t = "<b>{}:</b>".format(title.upper().strip()) if title else ""
 
-                user_message = "{}{}".format(t,
-                                             ''.join(["<br>&nbsp;&nbsp;+&nbsp;{}".format(x.strip()) for x in
-                                                      msg.strip().split('\n')])
-                                             )
+                user_message = "{}{}".format(
+                    t,
+                    "".join(
+                        [
+                            "<br>&nbsp;&nbsp;+&nbsp;{}".format(x.strip())
+                            for x in msg.strip().split("\n")
+                        ]
+                    ),
+                )
             else:
                 user_message = "{}".format(msg.strip().replace("\n", "<br>"))
 
-            display(HTML(f"""
+            display(
+                HTML(
+                    f"""
                 <div style="padding: 7px;
                             border-radius: 4px;
                             background-color: #d4ecd9;
@@ -417,12 +452,16 @@ def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"
                     <p>{user_message}</p>
                 </div>
 
-                """))
+                """
+                )
+            )
 
-        elif display_type.lower() == 'warning':
+        elif display_type.lower() == "warning":
             user_message = "{}".format(msg.strip().replace("\n", "<br>"))
 
-            display(HTML(f"""
+            display(
+                HTML(
+                    f"""
                 <div style="padding: 7px;
                             border-radius: 4px;
                             background-color: #fcc5c5;
@@ -431,12 +470,16 @@ def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"
                     <p>{user_message}</p>
                 </div>
 
-                """))
+                """
+                )
+            )
 
-        elif display_type.lower() == 'error':
+        elif display_type.lower() == "error":
             user_message = "{}".format(msg.strip().replace("\n", "<br>"))
 
-            display(HTML(f"""
+            display(
+                HTML(
+                    f"""
                 <div style="padding: 7px;
                             border-radius: 4px;
                             background-color: #4f053b;
@@ -446,9 +489,11 @@ def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"
                     <p>{user_message}</p>
                 </div>
 
-                """))
+                """
+                )
+            )
 
-        elif display_type.startswith('info'):
+        elif display_type.startswith("info"):
 
             user_message = msg.strip().replace("\n", "<br>")
 
@@ -472,7 +517,9 @@ def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"
             else:
                 title_html = ""
 
-            display(HTML(f"""
+            display(
+                HTML(
+                    f"""
             <br>
 
             <div style="width: calc(100% -20px);
@@ -485,7 +532,9 @@ def print_user_message(msg, display_type='tip', see_also_links=None, title="Tip"
                 {see_also_html}
             </div>
 
-            """))
+            """
+                )
+            )
 
 
 # take a series which can be interpreted as a dict, index=key, this
@@ -524,7 +573,7 @@ def ellipsis_strings(raw, n=24):
         else:
             n2 = int(n) // 2 - 3
             n1 = n - n2 - 3
-            result.append('{0}...{1}'.format(s[:n1], s[-n2:]))
+            result.append("{0}...{1}".format(s[:n1], s[-n2:]))
 
     return result
 
@@ -563,7 +612,7 @@ def replace_spaces(lst):
 
     lst: list of strings
     """
-    return [s.replace(' ', '_') for s in lst]
+    return [s.replace(" ", "_") for s in lst]
 
 
 def get_progress_bar(max_progress, description="Initializing"):
@@ -573,21 +622,22 @@ def get_progress_bar(max_progress, description="Initializing"):
     # this will return either a DummyProgressBar (non-notebook) or TqdmProgressBar (notebook environement)
     #
     if is_notebook():  # pragma: no cover
-        return TqdmProgressBar(max_progress, description=description, verbose=is_debug_mode())
+        return TqdmProgressBar(
+            max_progress, description=description, verbose=is_debug_mode()
+        )
     else:
         return DummyProgressBar()
 
 
 class JsonConverter(json.JSONEncoder):
-
     def default(self, obj):
         """
         Converts an object to JSON based on its type
 
         Parameters
         ----------
-        Obj: Object
-          An object which is being converted to Json, supported types are pandas Timestamp, series, dataframe, or categorical or numpy ndarrays.
+        obj: Object
+            An object which is being converted to Json, supported types are pandas Timestamp, series, dataframe, or categorical or numpy ndarrays.
 
         Returns
         -------
@@ -603,12 +653,24 @@ class JsonConverter(json.JSONEncoder):
             return json.loads(obj.to_json())
         if isinstance(obj, np.ndarray):
             return obj.tolist()
-        if isinstance(obj, (np.int_, np.intc, np.intp, np.int8,
-                            np.int16, np.int32, np.int64, np.uint8,
-                            np.uint16, np.uint32, np.uint64)):
+        if isinstance(
+            obj,
+            (
+                np.int_,
+                np.intc,
+                np.intp,
+                np.int8,
+                np.int16,
+                np.int32,
+                np.int64,
+                np.uint8,
+                np.uint16,
+                np.uint32,
+                np.uint64,
+            ),
+        ):
             return int(obj)
-        elif isinstance(obj, (np.float_, np.float16, np.float32,
-                              np.float64)):
+        elif isinstance(obj, (np.float_, np.float16, np.float32, np.float64)):
             return float(obj)
         elif isinstance(obj, (np.ndarray,)):
             return obj.tolist()
@@ -617,22 +679,29 @@ class JsonConverter(json.JSONEncoder):
 
 def split_data(X, y, random_state=random_state, test_size=test_size):
     """
-    Splits data using either Dask or Sklearn based on the input type of the data
+    Splits data using either Dask or Sklearn based on the input type of the data.
 
     Parameters
     ----------
     X: Either a Pandas or Dask Dataframe
-      The data points
+        The data points.
     y: Either a Pandas or Dask Dataframe
-      The labels
+        The labels.
     random_state: int
-      A random state for reproducability
+        A random state for reproducability.
     test_size: int
-      The number of elements that should be included in the test dataset
+        The number of elements that should be included in the test dataset.
     """
     from dask_ml.model_selection import train_test_split as dask_train_test_split
-    train_test_split = dask_train_test_split if isinstance(X, dd.core.DataFrame) else sklearn_train_test_split
-    return train_test_split(X, y, train_size=1 - test_size, test_size=test_size, random_state=random_state)
+
+    train_test_split = (
+        dask_train_test_split
+        if isinstance(X, dd.core.DataFrame)
+        else sklearn_train_test_split
+    )
+    return train_test_split(
+        X, y, train_size=1 - test_size, test_size=test_size, random_state=random_state
+    )
 
 
 def get_sqlalchemy_engine(connection_url, *args, **kwargs):
@@ -662,7 +731,9 @@ def get_sqlalchemy_engine(connection_url, *args, **kwargs):
         # need them.
         #
         # DAR: note: use echo=True to log engine output
-        _engines[connection_url] = create_engine(connection_url, pool_recycle=10, *args, **kwargs)
+        _engines[connection_url] = create_engine(
+            connection_url, pool_recycle=10, *args, **kwargs
+        )
 
     return _engines[connection_url]
 
@@ -670,15 +741,15 @@ def get_sqlalchemy_engine(connection_url, *args, **kwargs):
 def inject_and_copy_kwargs(kwargs, **args):
     """Takes in a dictionary and returns a copy with the args injected
 
-    example usage:
-        replace: foo(arg1, arg2, **kwargs)
-        with:    foo(arg1, args, utils.inject_and_copy_kwargs(kwargs, arg3=12, arg4=42))
+    Examples
+    ________
+    >>> foo(arg1, args, utils.inject_and_copy_kwargs(kwargs, arg3=12, arg4=42))
 
     Parameters
     ----------
     kwargs : dict
         The original `kwargs`.
-    args : type
+    **args : type
         A series of arguments, foo=42, bar=12 etc
 
     Returns
@@ -695,16 +766,15 @@ def inject_and_copy_kwargs(kwargs, **args):
     return d
 
 
-def flatten(d, parent_key=''):
+def flatten(d, parent_key=""):
     """
     Flattens nested dictionaries to a single layer dictionary
 
     Parameters
     ----------
-    d: dict
+    d : dict
         The dictionary that needs to be flattened
-
-    parent_key: str
+    parent_key : str
         Keys in the dictionary that are nested
 
     Returns
@@ -742,7 +812,11 @@ def get_base_modules(model):
             [add_bases.extend(get_base_modules(step)) for _, step in model.steps]
     except:
         pass
-    return add_bases + list(type(model).__mro__) if hasattr(type(model), "__mro__") else add_bases
+    return (
+        add_bases + list(type(model).__mro__)
+        if hasattr(type(model), "__mro__")
+        else add_bases
+    )
 
 
 def extract_lib_dependencies_from_model(model) -> dict:
@@ -751,7 +825,7 @@ def extract_lib_dependencies_from_model(model) -> dict:
 
     Parameters
     ----------
-    model - ADSModel
+    model
 
     Returns
     -------
@@ -760,8 +834,11 @@ def extract_lib_dependencies_from_model(model) -> dict:
     from pkg_resources import get_distribution
 
     module_versions = {}
-    modules_to_include = set(mod.__module__.split('.')[0] for mod in get_base_modules(model)
-                             if hasattr(mod, "__module__"))
+    modules_to_include = set(
+        mod.__module__.split(".")[0]
+        for mod in get_base_modules(model)
+        if hasattr(mod, "__module__")
+    )
     for mod in modules_to_include:
         if mod not in module_ignore:
             try:
@@ -772,19 +849,19 @@ def extract_lib_dependencies_from_model(model) -> dict:
     return module_versions
 
 
-def generate_requirement_file(requirements: dict, file_path: str, file_name: str = 'requirements.txt'):
+def generate_requirement_file(
+    requirements: dict, file_path: str, file_name: str = "requirements.txt"
+):
     """
     Generate requirements file at file_path.
 
     Parameters
     ----------
-    requirements: dict
+    requirements : dict
         Key is the library name and value is the version
-
-    file_path: str
+    file_path : str
         Directory to save requirements.txt
-
-    file_name: str
+    file_name : str
         Opional parameter to specify the file name
     """
 
@@ -796,64 +873,6 @@ def generate_requirement_file(requirements: dict, file_path: str, file_name: str
                 req_file.write("{}\n".format(lib))
 
 
-def generate_schema(X_sample=None, y_sample=None, **model_kwargs):
-    """
-    Generate a schema.
-
-    Parameters
-    ----------
-    X_sample: Pandas or Dask DataFrame
-        A sample of X data
-
-    y_sample: Pandas or Dask Series
-        A sample of y data
-
-    model_kwargs: Variable
-        Kwargs associated to the model
-
-    Returns
-    ----------
-    schema: Dict
-        The assembled Schema
-    data_sample: Dict
-        A sample of the data in the Schema
-    """
-    schema = {}
-    data_sample = {}
-    if X_sample is not None:
-        assert (isinstance(X_sample, pd.DataFrame) or
-                isinstance(X_sample, dd.core.DataFrame)), "X Sample must be a Pandas or Dask dataframe"
-        if isinstance(X_sample, dd.core.DataFrame):
-            X_sample_df = X_sample.compute()
-        else:
-            X_sample_df = X_sample
-        data_sample["input"] = np.asarray(X_sample_df.values)
-
-        # build schema
-        features = {}
-        for column in X_sample_df.columns.values:
-            feature_type, dtype = _get_feature_type_and_dtype(X_sample_df[column])
-            features[str(column)] = {"type": feature_type, "dtype": dtype}
-        schema["predict_arguments"] = features
-        if y_sample is None:
-            raise ValueError("Please specify y_sample corresponding to the given X_sample")
-    if y_sample is not None:
-        assert (isinstance(y_sample, pd.Series) or
-                isinstance(y_sample, dd.core.Series)), "y Sample must be a Pandas or Dask Series"
-        data_sample["output"] = np.asarray(y_sample.values)
-        feature_type, dtype = _get_feature_type_and_dtype(y_sample)
-        schema["predict_response"] = {y_sample.name: {"type": feature_type, "dtype": dtype}}
-    if len(data_sample) > 0:
-        if model_kwargs.get('is_classifier', False):
-            if len(model_kwargs.get('classes_', 0)) == 2:
-                schema["problem_type"] = "binary_classification"
-            else:
-                schema["problem_type"] = "multiclass_classification"
-        else:
-            schema["problem_type"] = "regression"
-    return schema, data_sample
-
-
 def _get_feature_type_and_dtype(column):
     feature_type = "unknown"
     dtype = column.dtype
@@ -863,4 +882,74 @@ def _get_feature_type_and_dtype(column):
         feature_type = "continuous"
     elif is_datetime64_dtype(dtype):
         feature_type = "datetime"
-    return feature_type, dtype.name
\ No newline at end of file
+    return feature_type, dtype.name
+
+
+def to_dataframe(
+    data: Union[
+        list,
+        tuple,
+        pd.Series,
+        np.ndarray,
+        pd.DataFrame,
+        dask.dataframe.core.Series,
+        dask.dataframe.core.DataFrame,
+    ]
+):
+    """
+    Convert to pandas DataFrame.
+
+    Parameters
+    ----------
+    data: Union[list, tuple, pd.Series, np.ndarray, pd.DataFrame, dask.dataframe.core.Series, dask.dataframe.core.DataFrame]
+        Convert data to pandas DataFrame.
+
+    Returns
+    _______
+    pd.DataFrame
+        pandas DataFrame.
+
+    """
+    if (
+        isinstance(data, np.ndarray)
+        or isinstance(data, list)
+        or isinstance(data, tuple)
+    ):
+        return pd.DataFrame(data)
+    elif isinstance(data, pd.Series):
+        return data.to_frame()
+    elif isinstance(data, dict):
+        try:
+            return pd.DataFrame.from_dict(data)
+        except:
+            raise NotImplementedError(
+                "Cannot convert this dictionary to a pandas DataFrame. \
+                    Check the structure to ensure it is tabular."
+            )
+    elif isinstance(data, pd.DataFrame):
+        return data
+    elif isinstance(data, dask.dataframe.core.DataFrame):
+        return data.compute()
+    else:
+        raise NotImplementedError(
+            f"The data type `{type(data)}` is not supported. Convert it to a pandas DataFrame."
+        )
+
+
+def _log_missing_module(module, package):
+    """
+    Log message for missing module
+    """
+    logger.info(f"The {module} module was not found. Install {package}.")
+
+
+def _log_multivalue_feature_column_error():
+    logger.error(
+        "A feature column has more than one value. Only a single value is allowed."
+    )
+
+
+def _log_plot_high_cardinality_warning(s, length):
+    logger.warning(
+        f"There are too many distinct values for {s} ({length:,}) to plot. Only the top {MAX_DISPLAY_VALUES}, by cardinality, will be used."
+    )
