@@ -36,17 +36,28 @@ import cloudpickle
 from fastparquet import ParquetFile, parquet_thrift
 from fastparquet.writer import write_common_metadata
 from graphviz import Digraph, Source
-from pandas.core.dtypes.common import is_numeric_dtype, is_bool_dtype, is_categorical_dtype, is_datetime64_any_dtype, \
-    is_float_dtype
+from pandas.core.dtypes.common import (
+    is_numeric_dtype,
+    is_bool_dtype,
+    is_categorical_dtype,
+    is_datetime64_any_dtype,
+    is_float_dtype,
+)
 
 from ads.common import utils
 from ads.dataset import logger
 from ads.type_discovery.type_discovery_driver import TypeDiscoveryDriver
-from ads.type_discovery.typed_feature import ContinuousTypedFeature, DateTimeTypedFeature, CategoricalTypedFeature, \
-    UnknownTypedFeature, OrdinalTypedFeature, DocumentTypedFeature
+from ads.type_discovery.typed_feature import (
+    ContinuousTypedFeature,
+    DateTimeTypedFeature,
+    CategoricalTypedFeature,
+    UnknownTypedFeature,
+    OrdinalTypedFeature,
+    DocumentTypedFeature,
+)
 
 
-class DatasetDefaults():
+class DatasetDefaults:
     sampling_confidence_level = 95
     sampling_confidence_interval = 1.0
 
@@ -62,7 +73,7 @@ def concatenate(X, y):
 
 
 def fix_column_names(X):
-    X.columns = X.columns.astype('str').str.strip().str.replace(' ', '_')
+    X.columns = X.columns.astype("str").str.strip().str.replace(" ", "_")
     return X
 
 
@@ -77,7 +88,9 @@ def convert_columns(df, feature_metadata=None, dtypes=None):
 
 
 def get_dtype(feature_type, dtype):
-    if isinstance(feature_type, ContinuousTypedFeature) or isinstance(feature_type, OrdinalTypedFeature):
+    if isinstance(feature_type, ContinuousTypedFeature) or isinstance(
+        feature_type, OrdinalTypedFeature
+    ):
         return dtype.name if is_numeric_dtype(dtype) else "float"
     elif isinstance(feature_type, DateTimeTypedFeature):
         return "datetime64[ns]" if not dtype.name.startswith("datetime") else dtype
@@ -101,11 +114,12 @@ def get_feature_type(name, series):
 
 def convert_to_html(plot):
     img = io.BytesIO()
-    plot.savefig(img, format='png',
-                 bbox_inches='tight')
+    plot.savefig(img, format="png", bbox_inches="tight")
     img.seek(0)
     encoded = base64.b64encode(img.getvalue())
-    return '<img width=95%" src="data:image/png;base64, {}"><hr><br>'.format(encoded.decode('utf-8'))
+    return '<img width=95%" src="data:image/png;base64, {}"><hr><br>'.format(
+        encoded.decode("utf-8")
+    )
 
 
 def _num_partitions_for_dataframe(df):
@@ -125,7 +139,13 @@ class ElaboratedPath:
     * A sqlalchemy connection url
     """
 
-    def __init__(self, source: Union[str, List[str]], format: str = None, name: str = None, **kwargs):
+    def __init__(
+        self,
+        source: Union[str, List[str]],
+        format: str = None,
+        name: str = None,
+        **kwargs,
+    ):
         """
         :param source:
         :param format:
@@ -151,9 +171,11 @@ class ElaboratedPath:
         else:
             raise ValueError(f"Source argument not understood: {source}")
         if self.num_paths == 0:
-            raise FileNotFoundError(f"Error: We could not find any files associated with the source: " \
-                                    f"{source}. Double check that this source is a valid glob pattern," \
-                                    f" directory, or path.")
+            raise FileNotFoundError(
+                f"Error: We could not find any files associated with the source: "
+                f"{source}. Double check that this source is a valid glob pattern,"
+                f" directory, or path."
+            )
         self._determine_format()
         self._determine_name()
 
@@ -185,7 +207,9 @@ class ElaboratedPath:
     def _determine_name(self):
         if self._name is None:
             if self._type == "list":
-                self._name = f"DataFrame from [{os.path.basename(self._original_source)}, ...]"
+                self._name = (
+                    f"DataFrame from [{os.path.basename(self._original_source)}, ...]"
+                )
             elif self._type == "glob":
                 self._name = f"DataFrame from {os.path.basename(self._original_source)}"
             else:
@@ -212,11 +236,14 @@ class ElaboratedPath:
             for i in range(min(self.num_paths, 5)):
                 format_keys.append(self._remove_compressions(self.paths[i]))
             if len(format_keys) == 0:
-                raise ValueError(f"Could not determine the format key for source: {self._original_source}")
+                raise ValueError(
+                    f"Could not determine the format key for source: {self._original_source}"
+                )
             if format_keys.count(format_keys[0]) != len(format_keys):
                 raise ValueError(
                     f"Got multiple formats from the source: {self._original_source}. Please run again "
-                    f"using the format parameter. Ex: format=<your format key, like: \"csv\", \"hdf\", etc.>")
+                    f'using the format parameter. Ex: format=<your format key, like: "csv", "hdf", etc.>'
+                )
             self._format = format_keys[0]
         else:
             self._format = self._format.lower()
@@ -237,27 +264,35 @@ class ElaboratedPath:
             self._type = "db"
         else:
             try:
-                self._fs = fsspec.filesystem(self._protocol, **self._kwargs.get("storage_options", dict()))
+                self._fs = fsspec.filesystem(
+                    self._protocol, **self._kwargs.get("storage_options", dict())
+                )
                 self._type = "glob"
             except ValueError:
                 try:
-                    self.engine = utils.get_sqlalchemy_engine(self._original_source, **self._kwargs)
+                    self.engine = utils.get_sqlalchemy_engine(
+                        self._original_source, **self._kwargs
+                    )
                     self._type = "db"
                 except:
                     if self._protocol in _known_db_protocols:
                         self._type = "db"
                     else:
-                        raise ValueError(f"Error in trying to understand the protocol for source: "
-                                         f"{self._original_source}. The protocol found: {self._protocol} is not "
-                                         f"registered with fsspec or sqlalchemy")
+                        raise ValueError(
+                            f"Error in trying to understand the protocol for source: "
+                            f"{self._original_source}. The protocol found: {self._protocol} is not "
+                            f"registered with fsspec or sqlalchemy"
+                        )
 
     @staticmethod
     def _remove_compressions(filename: str):
         for compression in _compression_to_extension.keys():
             if filename.strip().endswith(_compression_to_extension[compression]):
-                return ElaboratedPath._remove_compressions(os.path.splitext(filename.rstrip("/*"))[0])
+                return ElaboratedPath._remove_compressions(
+                    os.path.splitext(filename.rstrip("/*"))[0]
+                )
         format = os.path.splitext(filename.rstrip("/*"))[1][1:].lower()
-        return format.lower() if format != '' else None
+        return format.lower() if format != "" else None
 
 
 class DatasetLoadException(BaseException):
@@ -271,19 +306,25 @@ class DatasetLoadException(BaseException):
 def _get_dtype_from_error(e):
     error_string = str(e)
 
-    if 'mismatched dtypes' in error_string.lower():
+    if "mismatched dtypes" in error_string.lower():
 
         # For the mismatched dtypes error, dask either returns a error message containing the dtype argument
         # to specify, or  the found and expected dtypes in a table format, depending on what stage
         # the type inferencing fails. The below logic supports building the dtype dictionary for both cases
-        found_dtype_dict_str_list = re.findall(r'dtype=({[^{}]+})', error_string, re.MULTILINE)
+        found_dtype_dict_str_list = re.findall(
+            r"dtype=({[^{}]+})", error_string, re.MULTILINE
+        )
         if found_dtype_dict_str_list:
             found_dtype_dict = ast.literal_eval(found_dtype_dict_str_list[0])
         else:
             found_dtype_dict = _find_dtypes_from_table(error_string)
         if found_dtype_dict:
-            logger.warning("Dask type-inference/coercion failed. Retrying with dtype=%s.".format(found_dtype_dict),
-                           exc_info=True)
+            logger.warning(
+                "Dask type-inference/coercion failed. Retrying with dtype=%s.".format(
+                    found_dtype_dict
+                ),
+                exc_info=True,
+            )
             return found_dtype_dict
     return None
 
@@ -292,7 +333,9 @@ def _find_dtypes_from_table(error_string):
     error_lines = error_string.splitlines()
     dtypes = {}
     # matches '| Column | Found | Expected |'
-    pattern = re.compile("\\s*\\|\\s*Column\\s*\\|\\s*Found\\s*\\|\\s*Expected\\s*\\|\\s*")
+    pattern = re.compile(
+        "\\s*\\|\\s*Column\\s*\\|\\s*Found\\s*\\|\\s*Expected\\s*\\|\\s*"
+    )
     for i, line in enumerate(error_lines):
         if re.match(pattern, line):
             for j in range(i + 2, len(error_lines)):
@@ -327,14 +370,16 @@ def rename_duplicate_cols(original_cols):
     for col in original_cols:
         # remove any spaces form column names
         if isinstance(col, str):
-            col.replace(' ', '_')
+            col.replace(" ", "_")
         if col not in seen_col_names:
             new_cols.append(col)
         else:
             dup_count = seen_col_names[col]
             new_cols.append(f"{col}.{dup_count}")
         seen_col_names[col] += 1
-    assert (len(new_cols) == len(original_cols)), "There has been an error in re-naming duplicate columns"
+    assert len(new_cols) == len(
+        original_cols
+    ), "There has been an error in re-naming duplicate columns"
     return new_cols
 
 
@@ -359,7 +404,7 @@ def write_parquet(path, data, metadata_dict={}, storage_options=None):
     -------
     pf : ParquetFile
     """
-    assert (isinstance(data, dask.dataframe.core.DataFrame))
+    assert isinstance(data, dask.dataframe.core.DataFrame)
 
     # Write dataframe
     data.to_parquet(path, compression="GZIP", storage_options=storage_options)
@@ -388,17 +433,28 @@ def write_parquet(path, data, metadata_dict={}, storage_options=None):
 
 def is_text_data(df, target=None):
     if len(df.columns.values) == 2:
-        feature_name = list(set(df.columns.values) ^ set([target]))[0] if target else list(set(df.columns.values))[0]
+        feature_name = (
+            list(set(df.columns.values) ^ set([target]))[0]
+            if target
+            else list(set(df.columns.values))[0]
+        )
     elif len(df.columns.values == 1):
         feature_name = df.columns.values[0]
     else:
         return False
-    return isinstance(TypeDiscoveryDriver().discover(feature_name, df[feature_name]),
-                      DocumentTypedFeature)
+    return isinstance(
+        TypeDiscoveryDriver().discover(feature_name, df[feature_name]),
+        DocumentTypedFeature,
+    )
 
 
-def generate_sample(ddf: dd.DataFrame, n: int, confidence_level: int = DatasetDefaults.sampling_confidence_level,
-                    confidence_interval: float = DatasetDefaults.sampling_confidence_interval, **kwargs):
+def generate_sample(
+    ddf: dd.DataFrame,
+    n: int,
+    confidence_level: int = DatasetDefaults.sampling_confidence_level,
+    confidence_interval: float = DatasetDefaults.sampling_confidence_interval,
+    **kwargs,
+):
     min_size_to_sample = min(n, 10000)
 
     sample_size = None
@@ -407,24 +463,23 @@ def generate_sample(ddf: dd.DataFrame, n: int, confidence_level: int = DatasetDe
         requested_sample_size = int(kwargs["sample_max_rows"])
 
         if requested_sample_size < 0:
-            sample_size = calculate_sample_size(n, min_size_to_sample, confidence_level, confidence_interval)
+            sample_size = calculate_sample_size(
+                n, min_size_to_sample, confidence_level, confidence_interval
+            )
         else:
             if min_size_to_sample < requested_sample_size < n:
-                utils.print_user_message(
-                    "Sampling (from {} rows), to user specified {} rows for efficient graphing".format(n, kwargs[
-                        "sample_max_rows"]),
-                    display_type='info', title=None)
+                logger.info(
+                    f"Downsampling from {n} rows, to the user specified {requested_sample_size} rows for graphing."
+                )
                 sample_size = requested_sample_size
             elif requested_sample_size >= n:
-                utils.print_user_message(
-                    "Using entire dataset for graphing ({} rows)".format(n, kwargs["sample_max_rows"]),
-                    display_type='info',
-                    title=None)
+                logger.info(f"Using the entire dataset of {n} rows for graphing.")
                 sample_size = n
             else:
                 sample_size = min_size_to_sample
-                utils.print_user_message("Sampling (from {} rows) to {} rows for graphing".format(n, sample_size),
-                                         display_type='info', title=None)
+                logger.info(
+                    f"Downsampling from {n} rows, to {sample_size} rows for graphing."
+                )
 
     if sample_size and len(ddf) > sample_size:
         frac = min(1.0, sample_size * 1.05 / n)
@@ -434,7 +489,9 @@ def generate_sample(ddf: dd.DataFrame, n: int, confidence_level: int = DatasetDe
         return ddf.compute()
 
 
-def calculate_sample_size(population_size, min_size_to_sample, confidence_level=95, confidence_interval=1.0):
+def calculate_sample_size(
+    population_size, min_size_to_sample, confidence_level=95, confidence_interval=1.0
+):
     """Find sample size for a population using Cochran’s Sample Size Formula.
      With default values for confidence_level (percentage, default: 95%)
      and confidence_interval (margin of error, percentage, default: 1%)
@@ -454,7 +511,7 @@ def calculate_sample_size(population_size, min_size_to_sample, confidence_level=
         95: 1.96,
         99: 2.57,
         99.5: 2.807,
-        99.9: 3.291
+        99.9: 3.291,
     }
 
     p = 0.5
@@ -470,9 +527,7 @@ def calculate_sample_size(population_size, min_size_to_sample, confidence_level=
 
     sample_size = max(int(math.ceil(n)), min_size_to_sample)
 
-    utils.print_user_message(
-        "Auto sampling from {} to approx {} rows (confidence_level: {}, confidence_interval: {})".format(
-            population_size, sample_size, confidence_level, confidence_interval), display_type='info', title=None)
+    logger.info(f"Downsampling from {population_size} rows to {sample_size} rows.")
 
     return sample_size
 
@@ -494,46 +549,73 @@ def visualize_transformation(transformer_pipeline, text=None):
     dot = Digraph()
 
     # show a single node for paritions
-    dot.attr('node', shape='tab', style='filled', fontname='courier', fontsize='12', fontcolor='white',
-             resolution='144')
+    dot.attr(
+        "node",
+        shape="tab",
+        style="filled",
+        fontname="courier",
+        fontsize="12",
+        fontcolor="white",
+        resolution="144",
+    )
     if text:
-        dot.node('partitions', text, margin="0.25", fillcolor='dimgray')
+        dot.node("partitions", text, margin="0.25", fillcolor="dimgray")
 
-    dot.attr('node', shape='component', style='filled', fontname='courier', fontsize='10', fontcolor='black',
-             resolution='144')
+    dot.attr(
+        "node",
+        shape="component",
+        style="filled",
+        fontname="courier",
+        fontsize="10",
+        fontcolor="black",
+        resolution="144",
+    )
     for step in transformer_pipeline.steps:
-        name, clazz, clazzname, is_ads = step[0], step[1], step[1].__class__.__name__, 'ads' in str(step[1].__class__)
-        ads_node = str(step[1].__class__.__name__) in ['AutoMLPreprocessingTransformer', 'DataFrameTransformer',
-                                                       'RecommendationTransformer', 'AutoMLFeatureSelection',
-                                                       'FeatureEngineeringTransformer']
+        name, clazz, clazzname, is_ads = (
+            step[0],
+            step[1],
+            step[1].__class__.__name__,
+            "ads" in str(step[1].__class__),
+        )
+        ads_node = str(step[1].__class__.__name__) in [
+            "AutoMLPreprocessingTransformer",
+            "DataFrameTransformer",
+            "RecommendationTransformer",
+            "AutoMLFeatureSelection",
+            "FeatureEngineeringTransformer",
+        ]
         if ads_node:
-            text2html = "< {} >".format(html.escape(step[1].__repr__()).replace("\n", "<br/>"))
-            dot.node(name, text2html, margin="0.25", fillcolor='gold2')
+            text2html = "< {} >".format(
+                html.escape(step[1].__repr__()).replace("\n", "<br/>")
+            )
+            dot.node(name, text2html, margin="0.25", fillcolor="gold2")
         else:
-            dot.node(name, name.rsplit('/')[0], fillcolor='azure')
+            dot.node(name, name.rsplit("/")[0], fillcolor="azure")
 
     def format_label(stage):
-        if 'FunctionTransformer' in str(transformer_pipeline.steps[stage][1].__class__):
+        if "FunctionTransformer" in str(transformer_pipeline.steps[stage][1].__class__):
             return "<<font face='courier' point-size='10'>&nbsp;<b>{}</b>&nbsp;</font>>".format(
-                html.escape(transformer_pipeline.steps[stage][1].func.__name__))
+                html.escape(transformer_pipeline.steps[stage][1].func.__name__)
+            )
         else:
-            is_ads = 'ads' in str(transformer_pipeline.steps[stage][1].__class__)
+            is_ads = "ads" in str(transformer_pipeline.steps[stage][1].__class__)
             return "<<font face='courier' point-size='10'>&nbsp;<b>{}</b>&nbsp;</font>>".format(
-                transformer_pipeline.steps[stage][1].__class__.__name__)
+                transformer_pipeline.steps[stage][1].__class__.__name__
+            )
 
     edges = [x[0] for x in transformer_pipeline.steps]
     for i, edge in enumerate(list(zip(edges[:-1], edges[1:]))):
-        dot.edge(*edge, len='1.00', label=format_label(i))
+        dot.edge(*edge, len="1.00", label=format_label(i))
 
     # terminus node
-    dot.node('terminus', "", shape='terminator', fillcolor='white')
-    dot.edge(edges[-1], 'terminus', len='1.00', label=format_label(len(edges) - 1))
+    dot.node("terminus", "", shape="terminator", fillcolor="white")
+    dot.edge(edges[-1], "terminus", len="1.00", label=format_label(len(edges) - 1))
 
     graph = Source(dot)
-    display(SVG(graph.pipe(format='svg')))
+    display(SVG(graph.pipe(format="svg")))
 
 
-def up_sample(df, target, sampler='default', feature_types=None):
+def up_sample(df, target, sampler="default", feature_types=None):
     """
     Fixes imbalanced dataset by up-sampling
 
@@ -549,19 +631,21 @@ def up_sample(df, target, sampler='default', feature_types=None):
     -------
     upsampled_df : Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
     """
-    if sampler != 'default':
-        if inspect.getattr_static(sampler, 'fit_resample', None) is None:
-            raise AttributeError('`sampler` object must has method `fit_resample`.')
+    if sampler != "default":
+        if inspect.getattr_static(sampler, "fit_resample", None) is None:
+            raise AttributeError("`sampler` object must has method `fit_resample`.")
         else:
             # exactly two input args X, y will be passed to fit_resample()
-            # check signature of fit_sample 
+            # check signature of fit_sample
             num_no_default_params = 0
             sig = inspect.signature(sampler.fit_resample)
             for param in sig.parameters.values():
                 if param.default is param.empty:
                     num_no_default_params += 1
             if len(sig.parameters) < 2 or num_no_default_params > 2:
-                raise RuntimeError('The signature for `sampler.fit_resample` has to be `fit_resample(X, y)`.')
+                raise RuntimeError(
+                    "The signature for `sampler.fit_resample` has to be `fit_resample(X, y)`."
+                )
 
     X = df.drop(target, axis=1)
     y = df[target]
@@ -579,18 +663,21 @@ def up_sample(df, target, sampler='default', feature_types=None):
             elif column in feature_types and "median" in feature_types[column]["stats"]:
                 fill_nan_dict[column] = feature_types[column]["stats"]["median"]
             else:
-                utils.print_user_message("Sampling from Column that is missing values. This may cause an error",
-                                         display_type='error')
+                logger.warning(
+                    "Sampling from a column that has missing values may cause an error."
+                )
         X = X.fillna(fill_nan_dict)
 
-    if sampler == 'default':
-        imblearn_found = importlib.util.find_spec('imblearn') is not None
+    if sampler == "default":
+        imblearn_found = importlib.util.find_spec("imblearn") is not None
         if not imblearn_found:
-            raise ModuleNotFoundError("""
-                Required package for up-sampling `imblearn` not found. 
-                Please install `imblearn` with `pip install imbalanced-learn` 
+            raise ModuleNotFoundError(
+                """
+                Required package for up-sampling `imblearn` not found.
+                Please install `imblearn` with `pip install imbalanced-learn`
                 and rerun to enable up-sampling.
-            """)
+            """
+            )
         else:
             sampler = _get_imblearn_sampler(X, y)
     return _sample(sampler, X, y)
@@ -598,40 +685,24 @@ def up_sample(df, target, sampler='default', feature_types=None):
 
 def _get_imblearn_sampler(X, y):
     from imblearn.over_sampling import SMOTE, RandomOverSampler
+
     categorical_feature_indices = [
-        X.columns.get_loc(c) for c in
-        X.select_dtypes(include=['category', 'object', 'datetime64']).columns.values
+        X.columns.get_loc(c)
+        for c in X.select_dtypes(
+            include=["category", "object", "datetime64"]
+        ).columns.values
     ]
-    # ----------
-    # no longer use SMOTENC for data with categorical features, as imblearn's implementation
-    # could result in significant memory usage due to one-hot-encoding and numpy array slicing.
-    # ----------
-    # # SMOTENC fails when all features are categorical
-    # if len(X.select_dtypes(include=['category', 'object']).columns) == len(X.columns):
-    #     utils.print_user_message(
-    #         "All features are categorical. Up-sampling is only possible for datasets \
-    #         containing both continuous and categorical features.",
-    #         display_type='error', title='Error'
-    #     )
-    #     raise ValueError("""
-    #         Dataset contained only categorical features.
-    #         Make sure you have both continuous and categorical features in order for SMOTENC to work.
-    #     """)
 
     if len(categorical_feature_indices) > 0:
-        logger.info("""
-            Using RandomOverSampler for over sampling. 
+        logger.info(
+            """
+            Using the default `RandomOverSampler` sampler. Use `sample` to specify a sampler.
             Classes will be equalized.
-            You can also pass in other samplers such as `imblearn.SMOTENC` instead, e.g.    
+            You can also pass in other samplers such as `imblearn.SMOTENC` instead, e.g.
             sampler = SMOTENC(categorical_features=categorical_feature_indices)
             ds.up_sample(sampler=sampler)
-        """)
-        utils.print_user_message("""
-            Using RandomOverSampler for over sampling. 
-            You can also pass in other samplers such as `imblearn.SMOTENC` instead, e.g.    
-            sampler = SMOTENC(categorical_features=categorical_feature_indices)
-            ds.up_sample(sampler=sampler)
-        """, title='Info')
+        """
+        )
         return RandomOverSampler(random_state=42)
 
     if isinstance(y, pd.Series) or isinstance(y, pd.DataFrame):
@@ -642,23 +713,19 @@ def _get_imblearn_sampler(X, y):
     k_neighbors = min(min_sample_size - 1, 5)
     if k_neighbors == 0:
         logger.warning(
-            f"""k_neighbors is 0 as in the target there exists a class label that appeared only once. 
+            f"""k_neighbors is 0 as in the target there exists a class label that appeared only once.
                 SMOTE will fail. Default to RandomOverSampler.
             """
         )
         return RandomOverSampler(random_state=42)
     else:
         if 5 > k_neighbors > 0:
-            utils.print_user_message(
-                "<code>k_neighbors()</code> of SMOTE has changed to {}"
+            logger.info(
+                f"`k_neighbors()` of SMOTE has changed to {k_neighbors}"
                 " as the target has at least one class which appeared "
-                "only {} times in the data. The smaller <code>k_neighbors</code> is,"
-                "the high influence that the noise in the data will have on the "
-                "result.".format(k_neighbors, min_sample_size),
-                display_type='tip', title='Warning'
+                f"only {min_sample_size} times in the data. "
             )
-        logger.info('Using SMOTE for over sampling. Classes will be equalized.')
-        utils.print_user_message('Using SMOTE for over sampling.', title='Info')
+        logger.info("Using SMOTE for over sampling. Classes will be equalized.")
         return SMOTE(random_state=42, k_neighbors=k_neighbors)
 
 
@@ -676,31 +743,45 @@ def down_sample(df, target):
     downsampled_df : Union[pandas.DataFrame, dask.dataframe.core.DataFrame]
     """
     dfs = []
-    if isinstance(df, dd.core.DataFrame) and all([division is None for division in df.divisions]):
+    if isinstance(df, dd.core.DataFrame) and all(
+        [division is None for division in df.divisions]
+    ):
         # for dask dataframes, calling set_index will set the divisions. Concatenation with unknown divisions fails.
-        df = df.reset_index().set_index('index')
+        df = df.reset_index().set_index("index")
     target_value_counts = df[target].value_counts()
     min_key = min(target_value_counts.iteritems(), key=lambda k: k[1])
     for key, value in target_value_counts.iteritems():
         if key != min_key[0]:
-            dfs.append(df[df[target] == key].sample(frac=1 - ((value - min_key[1]) / value)))
+            dfs.append(
+                df[df[target] == key].sample(frac=1 - ((value - min_key[1]) / value))
+            )
     dfs.append(df[df[target] == min_key[0]])
-    return pd.concat(dfs) if isinstance(df, pd.DataFrame) else dd.concat(dfs, interleave_partitions=True)
+    return (
+        pd.concat(dfs)
+        if isinstance(df, pd.DataFrame)
+        else dd.concat(dfs, interleave_partitions=True)
+    )
 
 
 def _sample(sampler, X, y):
-    if isinstance(y, pd.Series) and (isinstance(y[0], bool) or isinstance(y[0], np.bool_)):
+    if isinstance(y, pd.Series) and (
+        isinstance(y[0], bool) or isinstance(y[0], np.bool_)
+    ):
         y_trans = y.astype(int)  ## Convert to ints to let SMOTE sample properly
         X_resampled, y_resampled = sampler.fit_resample(X=X, y=y_trans)
     else:
         X_resampled, y_resampled = sampler.fit_resample(X=X, y=y)
 
     if isinstance(X_resampled, pd.DataFrame):
-        X_resampled = dd.from_pandas(X_resampled, npartitions=_num_partitions_for_dataframe(X_resampled))
+        X_resampled = dd.from_pandas(
+            X_resampled, npartitions=_num_partitions_for_dataframe(X_resampled)
+        )
     else:
         X_resampled = dd.from_array(X_resampled, columns=X.columns.values)
     if isinstance(y_resampled, pd.Series):
-        y_resampled = dd.from_pandas(y_resampled, npartitions=_num_partitions_for_dataframe(y_resampled))
+        y_resampled = dd.from_pandas(
+            y_resampled, npartitions=_num_partitions_for_dataframe(y_resampled)
+        )
     else:
         y_resampled = dd.from_array(y_resampled, columns=[y.name])[y.name]
 
@@ -710,19 +791,24 @@ def _sample(sampler, X, y):
     return balanced_df.compute() if isinstance(X, pd.DataFrame) else balanced_df
 
 
-def get_fill_val(feature_types, column, action, constant='constant'):
+def get_fill_val(feature_types, column, action, constant="constant"):
     # action can be one of the following
     # "Fill missing values with mean", "Fill missing values with median",
     # "Fill missing values with frequent", "Fill missing values with constant"
-    action_ = action.split(' ')[-1]
-    fill_type = 'mode' if action_ == 'frequent' else action_
+    action_ = action.split(" ")[-1]
+    fill_type = "mode" if action_ == "frequent" else action_
     try:
-        fill_val = feature_types[column].meta_data["stats"][fill_type] if action_ != 'constant' else constant
+        fill_val = (
+            feature_types[column].meta_data["stats"][fill_type]
+            if action_ != "constant"
+            else constant
+        )
         fill_val = round(fill_val, 4) if isinstance(fill_val, Number) else fill_val
     except:
         fill_val = None
     return fill_val
 
+
 def parse_apache_log_str(x):
     """
     Returns the string delimited by two characters.
@@ -752,7 +838,8 @@ def parse_apache_log_datetime(x):
     """
     import pytz
     from datetime import datetime
-    dt = datetime.strptime(x[1:-7], '%d/%b/%Y:%H:%M:%S')
+
+    dt = datetime.strptime(x[1:-7], "%d/%b/%Y:%H:%M:%S")
     dt_tz = int(x[-6:-3]) * 60 + int(x[-3:-1])
     return dt.replace(tzinfo=pytz.FixedOffset(dt_tz))
 
@@ -770,3 +857,9 @@ def deprecate_default_value(var, old_value, new_value, warning_msg, warning_type
         return new_value
     else:
         return var
+
+
+def _log_yscale_not_set():
+    logger.info(
+        "`yscale` parameter is not set. Valid values are `'linear'`, `'log'`, `'symlog'`."
+    )
