@@ -133,13 +133,18 @@ class ModelEvaluator:
     def _get_binary_metrics(self):
         self._get_general_metrics()
         # add a metric to determine imbalance
-        self.metrics['balanced accuracy'] = metrics.balanced_accuracy_score(self.y_true, self.y_pred)
-        self.metrics['precision'] = metrics.precision_score(self.y_true, self.y_pred,
-                                                            pos_label=self.positive_class)
-        self.metrics['recall'] = metrics.recall_score(self.y_true, self.y_pred,
-                                                      pos_label=self.positive_class)
-        self.metrics['f1'] = metrics.f1_score(self.y_true, self.y_pred,
-                                              pos_label=self.positive_class, average='binary')
+        self.metrics["balanced accuracy"] = metrics.balanced_accuracy_score(
+            self.y_true, self.y_pred
+        )
+        self.metrics["precision"] = metrics.precision_score(
+            self.y_true, self.y_pred, pos_label=self.positive_class
+        )
+        self.metrics["recall"] = metrics.recall_score(
+            self.y_true, self.y_pred, pos_label=self.positive_class
+        )
+        self.metrics["f1"] = metrics.f1_score(
+            self.y_true, self.y_pred, pos_label=self.positive_class, average="binary"
+        )
 
         (
             self.metrics["false_positive_rate"],
@@ -331,40 +336,40 @@ class ModelEvaluator:
             )
 
         self.metrics["precision_weighted"] = metrics.precision_score(
-            y_true, y_pred, self.classes, average="weighted"
+            y_true, y_pred, labels=self.classes, average="weighted"
         )
         self.metrics["precision_micro"] = metrics.precision_score(
-            y_true, y_pred, self.classes, average="micro"
+            y_true, y_pred, labels=self.classes, average="micro"
         )
         self.metrics["precision_by_label"] = metrics.precision_score(
-            y_true, y_pred, self.classes, average=None
+            y_true, y_pred, labels=self.classes, average=None
         ).tolist()
         self.metrics["recall_weighted"] = metrics.recall_score(
-            y_true, y_pred, self.classes, average="weighted"
+            y_true, y_pred, labels=self.classes, average="weighted"
         )
         self.metrics["recall_micro"] = metrics.recall_score(
-            y_true, y_pred, self.classes, average="micro"
+            y_true, y_pred, labels=self.classes, average="micro"
         )
         self.metrics["recall_by_label"] = metrics.recall_score(
-            y_true, y_pred, self.classes, average=None
+            y_true, y_pred, labels=self.classes, average=None
         ).tolist()
         self.metrics["f1_weighted"] = metrics.f1_score(
-            y_true, y_pred, self.classes, average="weighted"
+            y_true, y_pred, labels=self.classes, average="weighted"
         )
         self.metrics["f1_micro"] = metrics.f1_score(
-            y_true, y_pred, self.classes, average="micro"
+            y_true, y_pred, labels=self.classes, average="micro"
         )
         self.metrics["f1_by_label"] = metrics.f1_score(
-            y_true, y_pred, self.classes, average=None
+            y_true, y_pred, labels=self.classes, average=None
         ).tolist()
         self.metrics["jaccard_weighted"] = metrics.jaccard_score(
-            y_true, y_pred, self.classes, average="weighted"
+            y_true, y_pred, labels=self.classes, average="weighted"
         )
         self.metrics["jaccard_micro"] = metrics.jaccard_score(
-            y_true, y_pred, self.classes, average="micro"
+            y_true, y_pred, labels=self.classes, average="micro"
         )
         self.metrics["jaccard_by_label"] = metrics.jaccard_score(
-            y_true, y_pred, self.classes, average=None
+            y_true, y_pred, labels=self.classes, average=None
         ).tolist()
 
         if self.y_score is not None:
@@ -462,6 +467,11 @@ class ModelEvaluator:
 
         for name, (fn, n_params) in scoring_functions.items():
             try:
-                self.metrics[name] = getattr(metrics, fn)(*(args[:n_params]))
+                if fn == "confusion_matrix":
+                    self.metrics[name] = getattr(metrics, fn)(
+                        **{"y_true": args[0], "y_pred": args[1], "labels": args[2]}
+                    )
+                else:
+                    self.metrics[name] = getattr(metrics, fn)(*(args[:n_params]))
             except Exception as e:
                 self.metrics[name] = f"Error unable to compute {fn}, due to: {e}"
