@@ -22,16 +22,19 @@ class MLXLocalExplainer(LocalExplainer):
         - Multi-class classification
         - Regression
     """
+
     def __init__(self):
         super(LocalExplainer, self).__init__()
         self.explainer = None
 
-    def explain(self,
-                row,
-                y=None,
-                num_features=None,
-                report_fidelity=True,
-                validation_percentiles=None):
+    def explain(
+        self,
+        row,
+        y=None,
+        num_features=None,
+        report_fidelity=True,
+        validation_percentiles=None,
+    ):
         """
         Explains the sample, row. Returns a local explanation object.
 
@@ -65,25 +68,26 @@ class MLXLocalExplainer(LocalExplainer):
         """
         if self.explainer is None:
             self._init_explainer()
-        assert (row is not None and isinstance(row, pd.DataFrame) and row.shape[0] == 1)
+        assert row is not None and isinstance(row, pd.DataFrame) and row.shape[0] == 1
 
         labels = list(range(len(self.class_names)))
 
         if num_features is None:
             num_features = len(row.columns.values)
 
-        explanation = self.explainer.compute(row.copy(),
-                                             y=None if y is None else y.copy(),
-                                             labels=labels,
-                                             verbose=False,
-                                             num_features=num_features,
-                                             report_fidelity=report_fidelity,
-                                             validation_percentiles=validation_percentiles)[0]
+        explanation = self.explainer.compute(
+            row.copy(),
+            y=None if y is None else y.copy(),
+            labels=labels,
+            verbose=False,
+            num_features=num_features,
+            report_fidelity=report_fidelity,
+            validation_percentiles=validation_percentiles,
+        )[0]
 
         return LocalExplanation(explanation, self.class_names)
 
-    def configure_local_explainer(self,
-                                  **kwargs):
+    def configure_local_explainer(self, **kwargs):
         """
         Validates the local explanation configuration parameters and initializes the local
         explainer with the provided configuration parameters.
@@ -107,16 +111,28 @@ class MLXLocalExplainer(LocalExplainer):
         MLXLocalExplainer
             Modified instance (self)
         """
-        avail_args = ['client', 'surrogate_model', 'num_samples', 'exp_sorting', 'scale_weight',
-                      'batch_size']
+        avail_args = [
+            "client",
+            "surrogate_model",
+            "num_samples",
+            "exp_sorting",
+            "scale_weight",
+            "batch_size",
+        ]
         for k, v in kwargs.items():
             if k not in avail_args:
-                raise ValueError('Unexpected argument for the local explainer: {}'.format(k))
-        if kwargs.get('client', None) is not None:
-            raise ValueError('Invalid client provided. Currently only supports disabling parallelization '
-                             'by setting client=None')
-        if kwargs.get('surrogate_model', None) not in ['linear', 'decision_tree', None]:
-            raise ValueError('Invalid surrogate_model provided. Currently only supports linear or decision_tree')
+                raise ValueError(
+                    "Unexpected argument for the local explainer: {}".format(k)
+                )
+        if kwargs.get("client", None) is not None:
+            raise ValueError(
+                "Invalid client provided. Currently only supports disabling parallelization "
+                "by setting client=None"
+            )
+        if kwargs.get("surrogate_model", None) not in ["linear", "decision_tree", None]:
+            raise ValueError(
+                "Invalid surrogate_model provided. Currently only supports linear or decision_tree"
+            )
 
         self._init_explainer(**kwargs)
         return self
@@ -134,8 +150,7 @@ class MLXLocalExplainer(LocalExplainer):
             self._init_explainer()
         return self.explainer.show_in_notebook()
 
-    def _init_explainer(self,
-                        **kwargs):
+    def _init_explainer(self, **kwargs):
         """
         Internal function to initialize the local explainer.
 
@@ -146,9 +161,17 @@ class MLXLocalExplainer(LocalExplainer):
         """
         if self.mode == "regression":
             self.class_names_ = ["Target"]
-        self.explainer = init_lime_explainer(self.explainer, self.est, self.X_train, self.y_train, self.mode,
-                                             class_names=self.class_names, use_pre_selected_features=True,
-                                             **kwargs)
+        self.explainer = init_lime_explainer(
+            self.explainer,
+            self.est,
+            self.X_train,
+            self.y_train,
+            self.mode,
+            class_names=self.class_names,
+            use_pre_selected_features=True,
+            **kwargs
+        )
+
 
 class LocalExplanation:
     """
@@ -157,20 +180,16 @@ class LocalExplanation:
     Contains functions to visualize the explanation and extract the
     raw explanation data.
     """
-    def __init__(self,
-                 explanation,
-                 class_names):
+
+    def __init__(self, explanation, class_names):
         self.explanation = explanation
         self.class_names = class_names
         if isinstance(self.class_names, np.ndarray):
             self.class_names = self.class_names.tolist()
 
-    def show_in_notebook(self,
-                         mode='lime',
-                         labels=None,
-                         colormap=None,
-                         return_wordcloud=False,
-                         **kwargs):
+    def show_in_notebook(
+        self, mode="lime", labels=None, colormap=None, return_wordcloud=False, **kwargs
+    ):
         """
         Generate a local explanation visualization for this explanation object.
 
@@ -213,20 +232,24 @@ class LocalExplanation:
             returns the wordcloud
         """
         if labels is None:
-            if len(self.class_names) > 1:  # classification
-                utils.print_user_message("Specify <code>'labels'</code> to plot the local explanation for specific target labels")
             labels = (0,)
         if np.isscalar(labels):
             labels = [labels]
-        labels = [self.class_names.index(label) if isinstance(label, str) else label for label in labels]
-        return self.explanation.show_in_notebook(mode=mode, labels=labels,
-                                                 colormap=colormap,
-                                                 return_wordcloud=return_wordcloud,
-                                                 **kwargs)
+        labels = [
+            self.class_names.index(label) if isinstance(label, str) else label
+            for label in labels
+        ]
+        return self.explanation.show_in_notebook(
+            mode=mode,
+            labels=labels,
+            colormap=colormap,
+            return_wordcloud=return_wordcloud,
+            **kwargs
+        )
 
     def get_diagnostics(self):
         """
-        Extracts the raw explanation and evaluation data from the explanation object to generate 
+        Extracts the raw explanation and evaluation data from the explanation object to generate
         the visualizations.
 
         Return
