@@ -5,7 +5,7 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import json
-import oci
+import oci.ai_language
 
 from ads.common import auth as authutil
 from ads.common import oci_client
