@@ -10,9 +10,10 @@ import os
 import time
 from typing import Dict, Optional, List
 import urllib.parse
+import io
 
 import fsspec
-import oci
+import oci.data_flow
 import ocifs
 import yaml
 from IPython.display import display, HTML
@@ -28,6 +29,7 @@ from ads.jobs.builders.infrastructure.utils import (
     batch_convert_case,
 )
 from ads.jobs.builders.runtimes.python_runtime import DataFlowRuntime
+from tqdm import tqdm
 
 
 class DataFlowApp(OCIModelMixin, oci.data_flow.models.Application):
@@ -305,13 +307,19 @@ class DataFlow(Infrastructure):
             defaults["compartment_id"] = os.environ["NB_SESSION_COMPARTMENT_OCID"]
         if "NB_SESSION_OCID" in os.environ:
             dsc_client = OCIClientFactory(**default_signer()).data_science
-            nb_session = dsc_client.get_notebook_session(
-                os.environ["NB_SESSION_OCID"]
-            ).data
-            nb_config = nb_session.notebook_session_configuration_details
-            if nb_config.shape in allowed_shapes:
-                defaults["driver_shape"] = nb_config.shape
-                defaults["executor_shape"] = nb_config.shape
+            try:
+                nb_session = dsc_client.get_notebook_session(
+                    os.environ["NB_SESSION_OCID"]
+                ).data
+                nb_config = nb_session.notebook_session_configuration_details
+                if nb_config.shape in allowed_shapes:
+                    defaults["driver_shape"] = nb_config.shape
+                    defaults["executor_shape"] = nb_config.shape
+            except Exception as e:
+                print(
+                    f"Error fetching details about Notebook session: {os.environ['NB_SESSION_OCID']}. {e}"
+                )
+
         defaults["language"] = "PYTHON"
         defaults["spark_version"] = "2.4.4"
         defaults["num_executors"] = 1
@@ -576,6 +584,7 @@ class DataFlow(Infrastructure):
             raise ValueError(
                 "Compartment id is required. Please specify compartment id via 'with_compartment_id()'."
             )
+        payload.pop("id", None)
         self.df_app = DataFlowApp(**payload).create()
         self.with_id(self.df_app.id)
         return self
@@ -586,13 +595,29 @@ class DataFlow(Infrastructure):
         os_client = OCIClientFactory(**signer).object_storage
         namespace = os_client.get_namespace().data
         parsed = urllib.parse.urlparse(bucket)
+        chunk_size = io.DEFAULT_BUFFER_SIZE
         if parsed.scheme == "oci":
-            dst_path = f"{bucket}/{os.path.basename(local_path)}"
+            dst_path = os.path.join(bucket, os.path.basename(local_path))
         else:
             dst_path = f"oci://{bucket}@{namespace}/{os.path.basename(local_path)}"
         with fsspec.open(dst_path, mode="wb", **signer) as fto:
-            with fsspec.open(local_path, mode="rb") as ffrom:
-                fto.write(ffrom.read())
+            file_system_clz = fsspec.get_filesystem_class(
+                urllib.parse.urlparse(local_path).scheme or "file"
+            )
+            file_size = file_system_clz().info(local_path)["size"]
+            with fsspec.open(local_path, mode="rb", encoding=None) as fread:
+                with tqdm.wrapattr(
+                    fread,
+                    "read",
+                    desc=f"Uploading file: {local_path} to {dst_path}",
+                    total=file_size,
+                ) as ffrom:
+                    while True:
+                        chunk = ffrom.read(chunk_size)
+                        if chunk:
+                            fto.write(chunk)
+                        else:
+                            break
         return dst_path
 
     def run(
