@@ -13,7 +13,7 @@ from io import DEFAULT_BUFFER_SIZE
 from typing import Dict, List, Optional, Union
 
 import fsspec
-import oci
+import oci.data_science
 import yaml
 from ads.common.oci_datascience import DSCNotebookSession, OCIDataScienceMixin
 from ads.common.oci_logging import OCILog
