@@ -24,7 +24,16 @@ def experimental(cls):
 
 class PY4JGateway:
     def __init__(self) -> None:
-        from py4j.java_gateway import GatewayParameters, JavaGateway, launch_gateway
+        try:
+            from py4j.java_gateway import GatewayParameters, JavaGateway, launch_gateway
+        except ModuleNotFoundError:
+            raise ModuleNotFoundError("py4j is not installed.")
+        if "CONDA_PREFIX" not in os.environ or not os.path.exists(
+            os.path.join(os.environ.get("CONDA_PREFIX"), "text-extraction-tools.jar")
+        ):
+            raise NotSupportedError(
+                "Tika is not supported in this distribution. Please use alternatives such as pdfplumber."
+            )
         port = launch_gateway(
             java_path="/usr/bin/java",
             classpath=os.path.join(
