@@ -7,7 +7,7 @@
 import ast
 import base64
 import json
-import oci
+import oci.vault
 import uuid
 
 from oci.vault import VaultsClientCompositeOperations
